class_accuracy: Class accuracy

Description Usage Arguments Value

View source: R/class_accuracy.R

Description

'class_accuracy()' provides common classification metrics to convey results business users will understand.

Usage

1
class_accuracy(df, truth, pred, pos_flag = 1)

Arguments

df

tibble

A data frame containing the truth and prediction columns

truth

factor

A column identifier for the true class results (that is a factor). This should be an unquoted column name.

pred

factor

A column identifier for the predicted class results (that is also a factor). This should be an unquoted column name.

pos_flag

numeric/factor

A numeric or string indicating the "positive" class.

Value

A tibble


mtfairbanks/graingr documentation built on Nov. 18, 2019, 8:39 a.m.