Description Usage Arguments Value
View source: R/class_accuracy.R
'class_accuracy()' provides common classification metrics to convey results business users will understand.
1 | class_accuracy(df, truth, pred, pos_flag = 1)
|
df |
tibble A data frame containing the truth and prediction columns |
truth |
factor A column identifier for the true class results (that is a factor). This should be an unquoted column name. |
pred |
factor A column identifier for the predicted class results (that is also a factor). This should be an unquoted column name. |
pos_flag |
numeric/factor A numeric or string indicating the "positive" class. |
A tibble
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.